==> cloud-5.0.0-rc2.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/ec2/security_group.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_SECURITY_GROUP_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Security group',
        keyValueRecords: [
          { type: 'default', labelName: 'Security group name', name: 'group_name', defaultValue: '', required: true },
          { type: 'default', labelName: 'Description', name: 'description', defaultValue: '', required: true },
          {
            type: 'select', labelName: 'VPC CIDR (ID)', name: 'vpc_id',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/vpc_options',
            defaultValue: ''
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{group_name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Security group',
        keyValueRecords: [
          { labelName: 'Name', name: 'group_name', type: 'default', defaultValue: '', required: true },
          { labelName: 'Security group name', name: 'group_name', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'ID', name: 'group_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Description', name: 'description', type: 'default', defaultValue: '', readOnly: true },
          {
            labelName: 'VPC ID', name: 'vpc_id', type: 'join', info: {
              entityTypeId: 'aws_cloud_vpc',
              keyColumn: 'vpc_id',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Created', name: 'created', type: 'datetime', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Rules',
        keyValueRecords: [
          { labelName: 'Inbound Rules', name: 'ip_permission', type: 'sg_permission', defaultValue: [] },
          { labelName: 'Outbound Rules', name: 'outbound_permission', type: 'sg_permission', defaultValue: [] },
        ]
      }
    ],
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'revoke',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to revoke the following permission?'
      },
    ],
    submitButtonLabel: 'Revoke'
  }
]

export default AWS_CLOUD_SECURITY_GROUP_TEMPLATE;

==> cloud-5.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/ec2/security_group.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_SECURITY_GROUP_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Security group',
        keyValueRecords: [
          { type: 'default', labelName: 'Security group name', name: 'group_name', defaultValue: '', required: true },
          { type: 'default', labelName: 'Description', name: 'description', defaultValue: '', required: true },
          {
            type: 'select', labelName: 'VPC CIDR (ID)', name: 'vpc_id',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/vpc_options',
            defaultValue: ''
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{group_name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Security group',
        keyValueRecords: [
          { labelName: 'Name', name: 'group_name', type: 'default', defaultValue: '', required: true },
          { labelName: 'Security group name', name: 'group_name', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'ID', name: 'group_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Description', name: 'description', type: 'default', defaultValue: '', readOnly: true },
          {
            labelName: 'VPC ID', name: 'vpc_id', type: 'join', info: {
              entityTypeId: 'aws_cloud_vpc',
              keyColumn: 'vpc_id',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Created', name: 'created', type: 'datetime', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Rules',
        keyValueRecords: [
          { labelName: 'Inbound rules', name: 'ip_permission', type: 'sg_permission', defaultValue: [] },
          { labelName: 'Outbound rules', name: 'outbound_permission', type: 'sg_permission', defaultValue: [] },
        ]
      }
    ],
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'security_group',
    actionType: 'revoke',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to revoke the following permission?'
      },
    ],
    submitButtonLabel: 'Revoke'
  }
]

export default AWS_CLOUD_SECURITY_GROUP_TEMPLATE;
